@@ -1,6 +1,6 @@
 #include "bigint.ih"
 
-BigInt const BigInt::rshiftc(size_t nBits) const
+BigInt BigInt::rshiftc(size_t nBits) const
 {
     BigInt ret(*this);
     ret.rshift(nBits);
