@@ -8,11 +8,11 @@ void DecryptBuf::done()
 
     if 
     (
-        !EVP_DecryptFinal_ex(&d_pimpl->ctx, 
+        !EVP_DecryptFinal_ex(d_pimpl->ctx, 
                             reinterpret_cast<unsigned char *>(d_pimpl->out), 
                             &outLen)
     )
-        throw Exception() << "Padding incorrect";
+        throw Exception{} << "Padding incorrect";
 
     d_pimpl->outStream.write(d_pimpl->out, outLen);
     d_pimpl->active = false;
