@@ -6,7 +6,7 @@ void Pattern::match(string const &text, int options)
                             d_nSub, d_subExpression, options);
 
     if (errcode)
-        throw Exception() << "Pattern::match(): no match";
+        throw Exception{} << "Pattern::match(): no match";
 
     d_text = text;
 
